Struct MainDevRow
pub struct MainDevRow {
pub entity: String,
pub main_dev: String,
pub metric: u64,
pub total: u64,
pub ownership: f64,
}Fields
entity: Stringmain_dev: Stringmetric: u64Numeric value of the metric for the winning author. Column header in
CSV is added / revisions / removed depending on the variant.
total: u64Sum of the metric across all authors for this entity. Header in CSV
is total-added / total-revisions / total-removed.
ownership: f64metric / total, rounded to 2 decimal places (code-maat parity).