Module arrow_facade

Module arrow_facade 

Single source of truth for Arrow types throughout the workspace.

Re-exports the version of arrow-rs that the duckdb crate currently depends on. When duckdb bumps arrow, we bump here in lockstep and the rest of the workspace stays unchanged.

Discipline: never use arrow::* directly anywhere else in the workspace. Always use codelore_lib::arrow_facade::* or use crate::arrow_facade::*. See spec 2.6.

Structs

BooleanBuilder
Builder for BooleanArray
Buffer
A contiguous memory region that can be shared with other buffers and across thread boundaries that stores Arrow data.
Field
Describes a single column in a Schema.
RecordBatch
A two-dimensional batch of column-oriented data with a defined schema.
Schema
Describes the meta-data of an ordered sequence of relative types.

Enums

ArrowError
Many different operations in the arrow crate return this error type.
DataType
Datatypes supported by this implementation of Apache Arrow.
TimeUnit
An absolute length of time in seconds, milliseconds, microseconds or nanoseconds.

Constants

ARROW_RUNTIME_VERSION
Version reported by the runtime (for provenance manifests).

Traits

Array
An array in the Arrow Columnar Format
ArrayBuilder
Trait for dealing with different array builders at runtime

Type Aliases

ArrayRef
A reference-counted reference to a generic Array
BinaryBuilder
Builder for BinaryArray
Date32Builder
A 32-bit date array builder.
Float64Builder
A 64-bit floating point array builder.
Int32Builder
A signed 32-bit integer array builder.
Int64Builder
A signed 64-bit integer array builder.
LargeBinaryBuilder
Builder for LargeBinaryArray
SchemaRef
A reference-counted reference to a Schema.
StringBuilder
Builder for StringArray
UInt32Builder
An usigned 32-bit integer array builder.
UInt64Builder
An usigned 64-bit integer array builder.