Function cache_key
pub fn cache_key(repo_path: &Path, head_sha: &str, opts: &Options) -> [u8; 32]Expand description
Compute a 32-byte SHA-256 cache key from:
canonical_repo_path || NUL || head_sha || NUL || CARGO_PKG_VERSION || NUL
|| opts_hash(opts) || NUL || CACHE_EPOCH
The key is deterministic for identical inputs and changes whenever any threshold knob or the cache epoch changes.