Module arrow_facade
Single source of truth for Arrow types throughout the workspace.
Re-exports the version of arrow-rs that the duckdb crate currently
depends on. When duckdb bumps arrow, we bump here in lockstep
and the rest of the workspace stays unchanged.
Discipline: never use arrow::* directly anywhere else in the
workspace. Always use codelore_lib::arrow_facade::* or use crate::arrow_facade::*.
See spec 2.6.
Structs
- Boolean
Builder - Builder for
BooleanArray - Buffer
- A contiguous memory region that can be shared with other buffers and across thread boundaries that stores Arrow data.
- Field
- Describes a single column in a
Schema. - Record
Batch - A two-dimensional batch of column-oriented data with a defined schema.
- Schema
- Describes the meta-data of an ordered sequence of relative types.
Enums
- Arrow
Error - Many different operations in the
arrowcrate return this error type. - Data
Type - Datatypes supported by this implementation of Apache Arrow.
- Time
Unit - An absolute length of time in seconds, milliseconds, microseconds or nanoseconds.
Constants
- ARROW_
RUNTIME_ VERSION - Version reported by the runtime (for provenance manifests).
Traits
- Array
- An array in the Arrow Columnar Format
- Array
Builder - Trait for dealing with different array builders at runtime
Type Aliases
- Array
Ref - A reference-counted reference to a generic
Array - Binary
Builder - Builder for
BinaryArray - Date32
Builder - A 32-bit date array builder.
- Float64
Builder - A 64-bit floating point array builder.
- Int32
Builder - A signed 32-bit integer array builder.
- Int64
Builder - A signed 64-bit integer array builder.
- Large
Binary Builder - Builder for
LargeBinaryArray - Schema
Ref - A reference-counted reference to a
Schema. - String
Builder - Builder for
StringArray - UInt32
Builder - An usigned 32-bit integer array builder.
- UInt64
Builder - An usigned 64-bit integer array builder.